@@ -2,11 +2,12 @@ package Liveman;
 use 5.22.0;
 use common::sense;
 
-our $VERSION = "1.0";
+our $VERSION = "1.1";
 
 use Term::ANSIColor qw/colored/;
 use File::Slurper qw/read_text write_text/;
 use Markdown::To::POD qw/markdown_to_pod/;
+use Text::Trim qw/trim/;
 
 
 # Конструктор
@@ -17,195 +18,6 @@ sub new {
     $self
 }
 
-# Пакет из пути
-sub _pkg($) {
-    ( shift =~ s!^lib/(.*)\.\w+$!$1!r ) =~ s!/!::!gr
-}
-
-# Переменная из пакета
-sub _var($) {
-    '$' . lcfirst( shift =~ s!::(\w)?!_${\lc $1}!gr )
-}
-
-# Для метода для вставки
-sub _md_method(@) {
-    my ($pkg, $sub, $args, $remark) = @_;
-    my $sub_args = "$sub ($args)";
-    $args = "($args)" if $args;
-
-    $remark = "." unless defined $remark;
-    my $var = _var $pkg;
-    << "END";
-## $sub_args
-
-$remark
-
-```perl
-my $var = $pkg->new;
-${var}->$sub$args  # -> .3
-```
-
-END
-}
-
-# Для фичи для вставки
-sub _md_feature(@) {
-    my ($pkg, $has, $remark) = @_;
-
-    $remark = "." unless defined $remark;
-    my $var = _var $pkg;
-    << "END";
-## $has
-
-$remark
-
-```perl
-my $var = $pkg->new;
-
-${var}->$has\t# -> .5
-```
-
-END
-}
-
-
-# Добавить разделы функций в *.md из *.pm
-sub appends {
-    my ($self) = @_;
-    my $files = $self->{files} // [split /\n/, `find lib -name '*.pm' -a -type f`];
-    $self->append($_) for @$files;
-    $self
-}
-
-# Добавить разделы функций в *.md из *.pm
-sub append {
-    my ($self, $pm) = @_;
-
-    my $md = $pm =~ s!(\.\w+)?$!.md!r;
-
-    die "Not file $pm!" if !-f $pm;
-    $self->mkmd($md) if !-f $md;
-
-    local $_ = read_text $pm;
-    my %sub; my %has;
-    while(m! (^\# [\ \t]* (?<remark> .*?) [\ \t]* )? \n (
-        sub \s+ (?<sub> (\w+|::)+ ) .* 
-            ( \s* my \s* \( \s* (\$self,? \s* )? (?<args>.*?) \s* \) \s* = \s* \@_; )?
-        | has \s+ (?<has> (\w+|'\w+'|"\w+"|\[ \s* ([^\[\]]*?) \s* \])+ )
-    ) !mgxn) {
-        $sub{$+{sub}} = {%+} if exists $+{sub} and "_" ne substr $+{sub}, 0, 1;
-        $has{$+{has}} = {%+} if exists $+{has} and "_" ne substr $+{has}, 0, 1;
-    }
-
-    return $self if !keys %sub && !keys %has;
-
-    $_ = read_text $md;
-
-    my $pkg = _pkg $md;
-
-    my $added = 0;
-
-    s{^\#[\ \t]+( (?<is>METHODS|SUBROUTINES) | DESCRIPTION )
-        (^```.*?^```|.)*? (?= ^\#\s)
-    }{
-        my $x = $&; my $is = $+{is};
-        if($is) {
-            while($x =~ /^\#\#[\ \t]+(\w+)/gm) {
-                delete $sub{$1};
-            }
-        }
-        $added += keys %sub;
-        join "", $x, $is? (): "# SUBROUTINES/METHODS\n\n", map { _md_method $pkg, $_, $sub{$_}{args}, $sub{$_}{remark} } sort keys %sub;
-    }emsx or die "Нет секции DESCRIPTION!" if keys %sub;
-
-    s{^\#[\ \t]+((?<is>FEATURES) | DESCRIPTION) 
-        (^```.*?^```|.)*? (?= ^\#\s)
-    }{
-        my $x = $&; my $is = $+{is};
-        if($is) {
-            while($x =~ /^\#\#[\ \t]+([^\n]+?)[\ \t]*/gm) {
-                delete $has{$1};
-            }
-        }
-        $added += keys %has;
-        join "", $x, $is? (): "# FEATURES\n\n", map { _md_feature $pkg, $_, $sub{$_}{remark} } sort keys %has;
-    }emsx or die "Нет секции DESCRIPTION!" if keys %has;
-
-
-    if ($added) {
-        write_text $md, $_;
-        print "🔖 $pm ", colored("⊂", "BRIGHT_GREEN"), " $md ", "\n",
-            "  ", scalar keys %has? (colored("FEATURES ", "BRIGHT_WHITE"), join(colored(", ", "red"), sort keys %has), "\n"): (),
-            "  ", scalar keys %sub? (colored("SUBROUTINES ", "BRIGHT_WHITE"), join(colored(", ", "red"), sort keys %sub), "\n"): (),
-        ;
-    } else {
-        print "🔖 $pm\n";
-    }
-
-    $self->{count}++;
-    $self->{added} = $added;
-    $self
-}
-
-sub _git_user_name { shift->{_git_user_name} //= _trim(`git config user.name`) }
-sub _git_user_email { shift->{_git_user_email} //= _trim(`git config user.email`) }
-sub _year { shift->{_year} //= _trim(`date +%Y`) }
-sub _license { shift->{_license} //= -r "minil.toml" && read_text("minil.toml") =~ /^\s*license\s*=\s*"([^"\n]*)"/m ? ($1 eq "perl_5"? "Perl5": uc($1) =~ s/_/v/r): "Perl5" }
-sub _land { shift->{_land} //= `curl "https://ipapi.co/\$(curl https://2ip.ru --connect-timeout 3 --max-time 3 -Ss)/json/" --connect-timeout 3 --max-time 3 -Ss` =~ /country_name": "([^"\n]*)"/ ? ($1 eq "Russia" ? "Rusland" : $1) : 'Rusland' }
-
-# Добавить разделы функций в *.md из *.pm
-sub mkmd {
-    my ($self, $md) = @_;
-
-    my $pkg = _pkg $md;
-
-    my $author = $self->_git_user_name;
-    my $email = $self->_git_user_email;
-    my $year = $self->_year;
-    my $license = $self->_license;
-    my $land = $self->_land;
-
-    write_text $md, << "END";
-# NAME
-
-$pkg - 
-
-# SYNOPSIS
-
-```perl
-use $pkg;
-
-my ${\_var $pkg} = $pkg->new;
-```
-
-# DESCRIPION
-
-.
-
-# SUBROUTINES
-
-# INSTALL
-
-For install this module in your system run next [command](https://metacpan.org/pod/App::cpm):
-
-```sh
-sudo cpm install -gvv $pkg
-```
-
-# AUTHOR
-
-$author [$email](mailto:$email)
-
-# LICENSE
-
-⚖ **$license**
-
-# COPYRIGHT
-
-The $pkg module is copyright © $year $author. $land. All rights reserved.
-END
-}
-
 # Получить путь к тестовому файлу из пути к md-файлу
 sub test_path {
     my ($self, $md) = @_;
@@ -274,11 +86,6 @@ sub _q_esc {
     $_[0] =~ s!'!\\'!gr
 }
 
-# Обрезает пробельные символы
-sub _trim {
-    $_[0] =~ s!^\s*(.*?)\s*\z!$1!sr
-}
-
 # Создаёт путь
 sub _mkpath {
     my ($p) = @_;
@@ -293,7 +100,7 @@ sub _to_testing {
 
     my $expected = $x{expected};
     my $q = _q_esc($line =~ s!\s*$!!r);
-    my $code = _trim($x{code});
+    my $code = trim($x{code});
 
     if(exists $x{is_deeply}) { "::is_deeply scalar do {$code}, scalar do {$expected}, '$q';\n" }
     elsif(exists $x{is})   { "::is scalar do {$code}, scalar do{$expected}, '$q';\n" }
@@ -330,7 +137,7 @@ sub transform {
 
         die "=== mark ===\n$mark\n=== sec1 ===\n$sec1\n=== code ===\n$code\n=== sec2 ===\n$sec2\n\nsec2 ne ```" if $sec2 ne "```\n";
 
-        $title = _trim($1) while $mark =~ /^#+[ \t]+(.*)/gm;
+        $title = trim($1) while $mark =~ /^#+[ \t]+(.*)/gm;
 
         push @pod, "\n", ($code =~ s/^/\t/gmr), "\n";
 
@@ -447,11 +254,11 @@ __END__
 
 =head1 NAME
 
-Liveman - markdown compiller to test and pod.
+Liveman - markdown compiller to test and pod
 
 =head1 VERSION
 
-1.0
+1.1
 
 =head1 SYNOPSIS
 
@@ -643,132 +450,6 @@ Tests C<t/**.t>-files.
 
 All if C<< $self-E<gt>{files} >> is empty, or C<< $self-E<gt>{files} >> only.
 
-=head2 mkmd ($md)
-
-It make md-file.
-
-=head2 appends ()
-
-Append to C<lib/**.md> from C<lib/**.pm> subroutines and features.
-
-=head2 append ($path)
-
-Append subroutines and features from the module with C<$path> into its documentation in the its sections.
-
-File lib/Alt/The/Plan.pm:
-
-	package Alt::The::Plan;
-	
-	sub planner {
-		my ($self) = @_;
-	}
-	
-	# This is first!
-	sub miting {
-		my ($self, $meet, $man, $woman) = @_;
-	}
-	
-	sub _exquise_me {
-		my ($self, $meet, $man, $woman) = @_;
-	}
-	
-	1;
-
-
-
-	-e "lib/Alt/The/Plan.md" # -> undef
-	
-	# Set the mocks:
-	*Liveman::_git_user_name = sub {'Yaroslav O. Kosmina'};
-	*Liveman::_git_user_email = sub {'dart@cpan.org'};
-	*Liveman::_year = sub {2023};
-	*Liveman::_license = sub {"Perl5"};
-	*Liveman::_land = sub {"Rusland"};
-	
-	my $liveman = Liveman->new->append("lib/Alt/The/Plan.pm");
-	$liveman->{count}	# -> 1
-	$liveman->{added}	# -> 2
-	
-	-e "lib/Alt/The/Plan.md" # -> 1
-	
-	# And again:
-	$liveman = Liveman->new->append("lib/Alt/The/Plan.pm");
-	$liveman->{count}	# -> 1
-	$liveman->{added}	# -> 0
-
-File lib/Alt/The/Plan.md is:
-
-	# NAME
-	
-	Alt::The::Plan - 
-	
-	# SYNOPSIS
-	
-	\```perl
-	use Alt::The::Plan;
-	
-	my $alt_the_plan = Alt::The::Plan->new;
-	\```
-	
-	# DESCRIPION
-	
-	.
-	
-	# SUBROUTINES
-	
-	## miting ($meet, $man, $woman)
-	
-	This is first!
-	
-	\```perl
-	my $alt_the_plan = Alt::The::Plan->new;
-	$alt_the_plan->miting($meet, $man, $woman)  # -> .3
-	\```
-	
-	## planner ()
-	
-	.
-	
-	\```perl
-	my $alt_the_plan = Alt::The::Plan->new;
-	$alt_the_plan->planner  # -> .3
-	\```
-	
-	# INSTALL
-	
-	For install this module in your system run next [command](https://metacpan.org/pod/App::cpm):
-	
-	\```sh
-	sudo cpm install -gvv Alt::The::Plan
-	\```
-	
-	# AUTHOR
-	
-	Yaroslav O. Kosmina [dart@cpan.org](mailto:dart@cpan.org)
-	
-	# LICENSE
-	
-	⚖ **Perl5**
-	
-	# COPYRIGHT
-	
-	The Alt::The::Plan module is copyright © 2023 Yaroslav O. Kosmina. Rusland. All rights reserved.
-
-=head1 INSTALL
-
-Add to B<cpanfile> in your project:
-
-	on 'test' => sub {
-		requires 'Liveman', 
-			git => 'https://github.com/darviarush/perl-liveman.git',
-			ref => 'master',
-		;
-	};
-
-And run command:
-
-	$ sudo cpm install -gvv
-
 =head1 AUTHOR
 
 Yaroslav O. Kosmina LL<mailto:dart@cpan.org>
@@ -779,4 +460,4 @@ Yaroslav O. Kosmina LL<mailto:dart@cpan.org>
 
 =head1 COPYRIGHT
 
-The Alt::The::Plan module is copyright © 2023 Yaroslav O. Kosmina. Rusland. All rights reserved.
+The Liveman module is copyright © 2023 Yaroslav O. Kosmina. Rusland. All rights reserved.
